pub fn yn(n: i32, x: f64) -> f64Expand description
Integer order of the Bessel function of the second kind (f64).
main (development) branch of crypto-glue.pub fn yn(n: i32, x: f64) -> f64Integer order of the Bessel function of the second kind (f64).