pub fn ynf(n: i32, x: f32) -> f32Expand description
Integer order of the Bessel function of the second kind (f32).
main (development) branch of crypto-glue.pub fn ynf(n: i32, x: f32) -> f32Integer order of the Bessel function of the second kind (f32).